;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "helm" "20260811.401"
  "Helm is an Emacs incremental and narrowing framework."
  '((helm-core "4.0.7")
    (wfnames   "1.2"))
  :url "https://emacs-helm.github.io/helm/"
  :commit "acff7751af0623f1bbebb1f3bf1ee4831f7f5035"
  :revdesc "acff7751af06"
  :keywords '("helm" "convenience" "files" "buffers" "grep" "completion" "lisp" "matching" "tools" "help" "package")
  :authors '(("Thierry Volpiatto" . "thievol@posteo.net"))
  :maintainers '(("Thierry Volpiatto" . "thievol@posteo.net")))
